' SocketTools 10 ActiveX Edition
' Copyright 2023 Catalyst Development Corporation
' All rights reserved
'
' This file is licensed to you pursuant to the terms of the
' product license agreement included with the original software,
' and is protected by copyright law and international treaties.
' Unauthorized reproduction or distribution may result in severe
' criminal penalties.
'
' This example demonstrates how to send a custom site command to
' an FTP server; in this particular example, it uses the CPWD command
' to change the password for the user. To run the sample, enter
' the following from the command line:
'
' cscript cpwd.vbs
'
' Note that because this sample uses standard input and output, it
' cannot be executed with the wscript.exe command
'

Option Explicit

Dim ftpClient
Dim strHostName
Dim strUserName
Dim strOldPassword
Dim strNewPassword
Dim nError

Const ftpOptionNone = 0
Const ftpOptionPassive = 1
Const ftpOptionFirewall = 2
Const ftpOptionNoAuth = 4
Const ftpOptionSecure = &H1000
Const ftpOptionExplicitSSL = &H2000

Set ftpClient = WScript.CreateObject("SocketTools.FtpClient.10")

nError = ftpClient.Initialize()
If nError > 0 Then
    WScript.Echo "Unable to initialize SocketTools component"
	WScript.Quit(1)
End If

'
' Prompt the user for their username, their current password and
' the new password that they want to use
'
WScript.StdOut.Write "Host Name: "
strHostName = WScript.StdIn.ReadLine

WScript.StdOut.Write "User Name: "
strUserName = WScript.StdIn.ReadLine

WScript.StdOut.Write "Old Password: "
strOldPassword = WScript.StdIn.ReadLine

WScript.StdOut.Write "New Password: "
strNewPassword = WScript.StdIn.ReadLine

'
' Initialize the properties to the values specified by the user,
' and set the Options property to specify a secure, explicit SSL
' session with the server
'
ftpClient.HostName = strHostName
ftpClient.UserName = strUserName
ftpClient.Password = strOldPassword
ftpClient.Options = ftpOptionPassive Or ftpOptionExplicitSSL

'
' Establish a connection with the server
'
nError = ftpClient.Connect()
If nError > 0 Then
    WScript.StdErr.WriteLine "Error " & nError & ": " & ftpClient.LastErrorString
	WScript.Quit(1)
End If

'
' Send the SITE CPWD command to the server, and display the result
' code and message returned by the server in response to the command
'
nError = ftpClient.Command("SITE", "CPWD " + strNewPassword)
WScript.StdOut.WriteLine ftpClient.ResultCode & " " & ftpClient.ResultString

'
' If an error occurred, then display the error message
'
If nError > 0 Then
    WScript.StdErr.WriteLine "Error " & nError & ": " & ftpClient.LastErrorString
	WScript.Quit(1)
End If

'
' Disconnect and uninitialize the object before terminating
'
ftpClient.Disconnect
ftpClient.Uninitialize
