' SocketTools 10 ActiveX Edition
' Copyright 2023 Catalyst Development Corporation
' All rights reserved
'
' This file is licensed to you pursuant to the terms of the
' product license agreement included with the original software,
' and is protected by copyright law and international treaties.
' Unauthorized reproduction or distribution may result in severe
' criminal penalties.
'

'
' Connect to an echo server, which echoes back any data that is
' sent to it; this serves as a basic test of network connectivity
' and demonstrates the fundamentals of establishing a connection,
' sending and receiving data and then terminating that connection.
' To use this sample, enter the following from the command line:
'
' cscript echo.vbs hostname [port]
'
' The hostname is the name of the server that you wish to connect
' to; the port is optional, and if not specified defaults to port 7.
' Note that because this script uses standard input and output, it
' cannot be executed with the wscript.exe command
'

Option Explicit

Const swError = -1
Const swProtocolTcp = 6
Const swPortEcho = 7
Const swBufferSize = 1024

Sub Socket_OnError(ByVal ErrorCode, ByVal Description)
	WScript.StdErr.WriteLine "OnError " & ErrorCode & ": " & Description
End Sub

Dim objSocket
Dim objArgs, nArg
Dim strLicenseKey
Dim strHostName
Dim nPort
Dim strBuffer
Dim nRead, nWrite, nError

Set objArgs = WScript.Arguments
If objArgs.Count < 1 Or objArgs.Count > 2 Then
    WScript.StdErr.WriteLine "Usage: " & WScript.ScriptName & " hostname port"
    WScript.Quit(1)
End If

Set objSocket = WScript.CreateObject("SocketTools.SocketWrench.10")
' WScript.ConnectObject objSocket, "Socket_"

'
' Initialize the object using the specified runtime license key;
' if the key is not specified, the development license will be used
'
strLicenseKey = "" ' Should be set to the runtime license key
nError = objSocket.Initialize(strLicenseKey) 
If nError <> 0 Then
    WScript.StdErr.WriteLine "Unable to initialize SocketWrench component"
    WScript.Quit(1)
End If

If objArgs.Count = 1 Then
    strHostName = objArgs(0)
    nPort = swPortEcho
Else
    strHostName = objArgs(0)
    nPort = objArgs(1)
End If

WScript.StdErr.Write "Connecting to " & strHostName & "..." & vbCr
nError = objSocket.Connect(strHostName, nPort)
If nError <> 0 Then
    WScript.StdErr.WriteLine "Unable to connect to " & strHostName & " (" & nError & ")"
    objSocket.Uninitialize
    WScript.Quit(1)
End If
WScript.StdErr.WriteLine "Connected to " & strHostName & " on port " & nPort
WScript.StdErr.WriteLine "Enter one or more lines of text, press Ctrl+Z to terminate input"

Do 
    If WScript.StdIn.AtEndOfStream Then Exit Do
    strBuffer = WScript.StdIn.ReadLine & vbCrLf

    nWrite = objSocket.Write(strBuffer, Len(strBuffer))
    If nWrite = -1 Then
        WScript.StdErr.WriteLine "Error writing to socket (" & objSocket.LastError & ")"
        Exit Do
    End If	    

    nRead = objSocket.Read(strBuffer, swBufferSize)
    If nRead > 1 Then
        WScript.StdOut.Write strBuffer
    ElseIf nRead = 0 Then
        Exit Do
    Else
        WScript.StdErr.WriteLine "Error reading from socket (" & objSocket.LastError & ")"
        Exit Do
    End If
Loop

objSocket.Disconnect
objSocket.Uninitialize
