' SocketTools 10 ActiveX Edition
' Copyright 2023 Catalyst Development Corporation
' All rights reserved
'
' This file is licensed to you pursuant to the terms of the
' product license agreement included with the original software,
' and is protected by copyright law and international treaties.
' Unauthorized reproduction or distribution may result in severe
' criminal penalties.
'

'
' Retrieve the specified file from an FTP server and store it
' it on the local system. The first parameter should specify
' the URL of the remote file, and the second parameter is the local
' file name.
'
Option Explicit

Dim objArgs
Dim objFtp
Dim strLicenseKey
Dim strRemoteURL
Dim strLocalFile
Dim nArg, nError

'
' Event handler for the OnProgress event, which fires periodically
' during the file transfer 
'
Sub FtpClient_OnProgress(ByVal FileName, ByVal FileSize, ByVal BytesCopied, ByVal Percent)
    WScript.StdOut.Write "Downloading " & FileName & " (" & Percent & "%)" & vbCr
End Sub

'
' Process command line arguments, making sure that a hostname
' has been specified and setting the strHostName and strFileName
' variables
'
Set objArgs = WScript.Arguments
If objArgs.Count < 1 Or objArgs.Count > 2 Then
    WScript.StdErr.WriteLine "Usage: " & WScript.ScriptName & " remoteurl filename"
    WScript.Quit(1)
End If

If objArgs.Count = 1 Then
    strRemoteURL = objArgs(0)
    strLocalFile = ""
Else
    strRemoteURL = objArgs(0)
    strLocalFile = objArgs(1)
End If

'
' Create an instance of the object
'
Set objFtp = WScript.CreateObject("SocketTools.FtpClient.10", "FtpClient_")

'
' Initialize the object using the specified runtime license key;
' if the key is not specified, the development license will be used
'
strLicenseKey = "" ' Should be set to the runtime license key
nError = objFtp.Initialize(strLicenseKey) 
If nError <> 0 Then
    WScript.Echo "Unable to initialize SocketTools component"
    WScript.Quit(1)
End If
    
' Setup error handling since the component will throw an error
' if an invalid URL is specified

On Error Resume Next: Err.Clear
objFtp.URL = strRemoteURL

' Check the Err object to see if an error has occurred, and
' if so, let the user know that the URL is invalid

If Err.Number <> 0 Then
    WScript.StdErr.WriteLine "The specified URL is invalid"
    WScript.Quit(1)
End If

' Reset error handling and connect to the server using the
' default property values that were updated when the URL
' property was set (ie: HostName, RemotePort, UserName, etc.)
On Error GoTo 0
nError = objFtp.Connect()

If nError <> 0 Then
    WScript.StdErr.WriteLine "Error " & objFtp.LastError & ": " & objFtp.LastErrorString
    WScript.Quit(1)
End If

' Change to the directory specified by the RemotePath property
nError = objFtp.ChangeDirectory(objFtp.RemotePath)
If nError <> 0 Then
    WScript.StdErr.WriteLine "Error " & objFtp.LastError & ": " & objFtp.LastErrorString
    WScript.Quit(1)
End If

' If the local file name was not specified, then use the remote
' file name by default
If strLocalFile = "" Then
    strLocalFile = objFtp.RemoteFile
End If

' Download the file to the local system
nError = objFtp.GetFile(objFtp.RemoteFile, strLocalFile)

If nError = 0 Then
    WScript.StdOut.WriteLine "Downloaded " & strRemoteURL & " to " & strLocalFile
Else
    WScript.StdErr.WriteLine "Error " & objFtp.LastError & ": " & objFtp.LastErrorString
    WScript.Quit(1)
End If

objFtp.Uninitialize
