' SocketTools 10 ActiveX Edition
' Copyright 2023 Catalyst Development Corporation
' All rights reserved
'
' This file is licensed to you pursuant to the terms of the
' product license agreement included with the original software,
' and is protected by copyright law and international treaties.
' Unauthorized reproduction or distribution may result in severe
' criminal penalties.
'
' This example demonstrates how to download multiple files in a
' single method call using GetMultipleFiles, and how to establish
' an event handler for the OnProgress event. To run the sample, enter
' the following from the command line:
'
' cscript getfiles.vbs
'
' Note that because this sample uses standard input and output, it
' cannot be executed with the wscript.exe command
'

Option Explicit

Dim ftpClient
Dim strHostName
Dim strUserName
Dim strPassword
Dim strLocalDir
Dim strRemoteDir
Dim strWildcardMask
Dim strLastFile
Dim nFileCount
Dim nError

Const ftpOptionNone = 0
Const ftpOptionPassive = 1
Const ftpOptionFirewall = 2
Const ftpOptionNoAuth = 4
Const ftpOptionSecure = &H1000
Const ftpOptionExplicitSSL = &H2000

'
' Event handler for the OnProgress event, which fires periodically
' during the file transfer 
'
Sub FtpClient_OnProgress(ByVal FileName, ByVal FileSize, ByVal BytesCopied, ByVal Percent)
    If FileName <> strLastFile Then
	    nFileCount = nFileCount + 1
		strLastFile = FileName
        WScript.StdOut.Write vbCrLf
    End If
    WScript.StdOut.Write "Downloading " & FileName & " (" & Percent & "%)" & vbCr
End Sub

Set ftpClient = WScript.CreateObject("SocketTools.FtpClient.10", "FtpClient_")

nError = ftpClient.Initialize()
If nError > 0 Then
    WScript.Echo "Unable to initialize SocketTools component"
	WScript.Quit(1)
End If

'
' Prompt the user for the hostname, their user name and their
' password
'
WScript.StdOut.Write "Host Name: "
strHostName = WScript.StdIn.ReadLine

WScript.StdOut.Write "User Name: "
strUserName = WScript.StdIn.ReadLine

WScript.StdOut.Write "Password: "
strPassword = WScript.StdIn.ReadLine

'
' Initialize the properties to the values specified by the user,
' and set the Options property to specify a secure, explicit SSL
' session with the server
'
ftpClient.HostName = strHostName
ftpClient.UserName = strUserName
ftpClient.Password = strPassword
ftpClient.Options = ftpOptionPassive

'
' Enable debug logging and store the output in a file in the
' current directory
'
ftpClient.TraceFile = "getfiles.log"
ftpClient.TraceFlags = 4
ftpClient.Trace = True

'
' Establish a connection with the server
'
nError = ftpClient.Connect()
If nError > 0 Then
    WScript.StdErr.WriteLine "Error " & nError & ": " & ftpClient.LastErrorString
	WScript.Quit(1)
End If

WScript.StdOut.WriteLine vbCrLf & "Connected to " & ftpClient.HostName

'
' Prompt the user for the local directory where files will be stored,
' the remote directory on the server and the wildcard mask, such as *.*
'
WScript.StdOut.Write "Local Directory: "
strLocalDir = WScript.StdIn.ReadLine

WScript.StdOut.Write "Remote Directory: "
strRemoteDir = WScript.StdIn.ReadLine

WScript.StdOut.Write "Wildcard Mask: "
strWildcardMask = WScript.StdIn.ReadLine

nError = ftpClient.GetMultipleFiles(strLocalDir, strRemoteDir, strWildcardMask)
If nError > 0 Then
    WScript.StdErr.WriteLine "Error " & nError & ": " & ftpClient.LastErrorString
	WScript.Quit(1)
End If

WScript.StdOut.WriteLine vbCrLf & "Downloaded " & nFileCount & " files"

ftpClient.Disconnect
ftpClient.Uninitialize
