' SocketTools 10 ActiveX Edition
' Copyright 2023 Catalyst Development Corporation
' All rights reserved
'
' This file is licensed to you pursuant to the terms of the
' product license agreement included with the original software,
' and is protected by copyright law and international treaties.
' Unauthorized reproduction or distribution may result in severe
' criminal penalties.
'
' This example demonstrates how to download multiple files in a
' single method call using GetMultipleFiles, and how to establish
' an event handler for the OnProgress event. To run the sample, enter
' the following from the command line:
'
' cscript listfiles.vbs
'
' Note that because this sample uses standard input and output, it
' cannot be executed with the wscript.exe command
'

Option Explicit

Dim ftpClient
Dim strHostName
Dim strUserName
Dim strPassword
Dim strDirectory
Dim strFileName
Dim strFileDate
Dim strFileOwner
Dim strFileGroup
Dim nFileSize
Dim nFilePerms
Dim bIsDirectory
Dim nFileCount
Dim nError

Const ftpOptionNone = 0
Const ftpOptionPassive = 1
Const ftpOptionFirewall = 2
Const ftpOptionNoAuth = 4
Const ftpOptionSecure = &H1000
Const ftpOptionExplicitSSL = &H2000
Const stErrorEndOfDirectory = 12269

Set ftpClient = WScript.CreateObject("SocketTools.FtpClient.10")

nError = ftpClient.Initialize()
If nError > 0 Then
    WScript.Echo "Unable to initialize SocketTools component"
	WScript.Quit(1)
End If

'
' Prompt the user for the hostname, their user name and their
' password
'
WScript.StdOut.Write "Host Name: "
strHostName = WScript.StdIn.ReadLine

WScript.StdOut.Write "User Name: "
strUserName = WScript.StdIn.ReadLine

WScript.StdOut.Write "Password: "
strPassword = WScript.StdIn.ReadLine

'
' Initialize the properties to the values specified by the user,
' and set the Options property to specify a secure, explicit SSL
' session with the server
'
ftpClient.HostName = strHostName
ftpClient.UserName = strUserName
ftpClient.Password = strPassword
ftpClient.Options = ftpOptionPassive Or ftpOptionExplicitSSL

'
' Establish a connection with the server
'
nError = ftpClient.Connect()
If nError > 0 Then
    WScript.StdErr.WriteLine "Error " & nError & ": " & ftpClient.LastErrorString
	WScript.Quit(1)
End If

'
' Get the current working directory and store that in a variable
' passed to the method
'
nError = ftpClient.GetDirectory(strDirectory)
If nError > 0 Then
    WScript.StdErr.WriteLine "Error " & nError & ": " & ftpClient.LastErrorString
	WScript.Quit(1)
End If

WScript.StdOut.WriteLine vbCrLf & "The current directory is " & strDirectory

'
' Open the current working directory
'
nError = ftpClient.OpenDirectory()
If nError > 0 Then
    WScript.StdErr.WriteLine "Error " & nError & ": " & ftpClient.LastErrorString
	WScript.Quit(1)
End If

nFileCount = 0

'
' Begin reading information about each file in the directory;
' in this example, we will count only regular files and not
' subdirectories
'
Do
  nError = ftpClient.ReadDirectory(strFileName, nFileSize, strFileDate, strFileOwner, strFileGroup, nFilePerms, bIsDirectory)
  If nError = 0 Then
    If Not bIsDirectory Then
        nFileCount = nFileCount + 1
        WScript.StdOut.WriteLine strFileName & ", " & nFileSize & " bytes"
	End If
  End If
Loop Until nError > 0

'
' If an error other than stErrorEndOfDirectory is returned, then
' display that error message and terminate the script
'
If nError > 0 And nError <> stErrorEndOfDirectory Then
    WScript.StdErr.WriteLine "Error " & nError & ": " & ftpClient.LastErrorString
	WScript.Quit(1)
End If

'
' Close the directory and display the number of files listed; note that it
' is very important that the directory listing be closed with CloseDirectory
' after it has completed. Failure to do this will prevent subsequent file
' transfers from completing.
'
ftpClient.CloseDirectory
WScript.StdOut.WriteLine nFileCount & " files listed"

'
' Disconnect from the server and uninitialize the component
'
ftpClient.Disconnect
ftpClient.Uninitialize
