' SocketTools 10 ActiveX Edition
' Copyright 2023 Catalyst Development Corporation
' All rights reserved
'
' This file is licensed to you pursuant to the terms of the
' product license agreement included with the original software,
' and is protected by copyright law and international treaties.
' Unauthorized reproduction or distribution may result in severe
' criminal penalties.
'

'
' This demonstrates a basic SMTP client that prompts the user for
' input from the console, and then delivers a message to the
' specified recipient. To run the sample, enter the following from
' the command line:
'
' cscript listmail.vbs hostname username password
'
' Where the hostname is the name of the mail server to list
' messages on, the username and password are used to
' authenticate access to the user's mailbox
'

Option Explicit

Const popError = -1
Const popPortDefault = 110
Const popTimeout = 10

Dim objPop3, objMail
Dim strLicenseKey
Dim objArgs, nArg
Dim strHostName, strUserName, strPassword
Dim strHeaders
Dim nMessage, nError

'
' Create an instance of the SocketTools components
'
Set objPop3 = WScript.CreateObject("SocketTools.PopClient.10")
Set objMail = WScript.CreateObject("SocketTools.MailMessage.10")

'
' Initialize the scripting objects using the specified runtime license
' key; if the key is not specified, the development license will be used
'
strLicenseKey = "" ' Should be set to the runtime license key

nError = objPop3.Initialize(strLicenseKey) 
If nError <> 0 Then
    WScript.Echo "Unable to initialize SocketTools component"
    WScript.Quit(1)
End If

nError = objMail.Initialize(strLicenseKey) 
If nError <> 0 Then
    WScript.Echo "Unable to initialize SocketTools component"
    WScript.Quit(1)
End If

'
' Process command line arguments, making sure that a hostname
' has been specified and setting the strHostName and nPort
' variables
'
Set objArgs = WScript.Arguments
If objArgs.Count <> 3 Then
    WScript.StdErr.WriteLine "Usage: " & WScript.ScriptName & " hostname username password"
    WScript.Quit(1)
End If

strHostName = objArgs(0)
strUserName = objArgs(1)
strPassword = objArgs(2)

nError = objPop3.Connect(strHostName, popPortDefault, strUserName, strPassword)
If nError <> 0 Then
    WScript.StdErr.WriteLine "Error " & objPop3.LastError & ": " & objPop3.LastErrorString
    WScript.Quit(1)
End If

WScript.StdOut.WriteLine "There are " & objPop3.MessageCount & " messages in this mailbox"

For nMessage = 1 To objPop3.MessageCount
	nError = objPop3.GetHeaders(nMessage, strHeaders)
	If nError <> 0 Then
    	WScript.StdErr.WriteLine "Error " & objPop3.LastError & ": " & objPop3.LastErrorString
    	Exit For
	End If

	objMail.ClearMessage
	objMail.ParseMessage(strHeaders)

	WScript.StdOut.WriteLine nMessage & " - " & objMail.From & " - " & objMail.Subject
Next

objPop3.Disconnect
objPop3.Uninitialize
objMail.Uninitialize
