' SocketTools 10 ActiveX Edition
' Copyright 2023 Catalyst Development Corporation
' All rights reserved
'
' This file is licensed to you pursuant to the terms of the
' product license agreement included with the original software,
' and is protected by copyright law and international treaties.
' Unauthorized reproduction or distribution may result in severe
' criminal penalties.
'

'
' This demonstrates a basic SMTP client that prompts the user for
' input from the console, and then delivers a message to the
' specified recipient. To run the sample, enter the following from
' the command line:
'
' cscript sendmail.vbs hostname [port] [username] [password]
'
' Where the hostname is the name of the mail server to deliver the
' message to; if the optional port argument is not specified, the default
' SMTP port will be used. Note that because this sample uses standard
' input and output, it cannot be executed with the wscript.exe command
'

Option Explicit

Const smtpError = -1
Const smtpPortDefault = 110
Const smtpTimeout = 10

Dim objSmtp, objMail
Dim strLicenseKey
Dim objArgs, nArg
Dim strHostName, nHostPort
Dim strUserName, strPassword
Dim strFrom, strTo, strCc, strSubject
Dim strMessage
Dim strSender, strRecipients
Dim nIndex, nError

'
' Create an instance of the SocketTools components
'
Set objSmtp = WScript.CreateObject("SocketTools.SmtpClient.10")
Set objMail = WScript.CreateObject("SocketTools.MailMessage.10")

'
' Initialize the scripting objects using the specified runtime license
' key; if the key is not specified, the development license will be used
'
strLicenseKey = "" ' Should be set to the runtime license key

nError = objSmtp.Initialize(strLicenseKey) 
If nError <> 0 Then
    WScript.Echo "Unable to initialize SocketTools SMTP object"
    WScript.Quit(1)
End If

nError = objMail.Initialize(strLicenseKey) 
If nError <> 0 Then
    WScript.Echo "Unable to initialize SocketTools message object"
    WScript.Quit(1)
End If

'
' Process command line arguments, making sure that a hostname
' has been specified and setting the strHostName and nPort
' variables
'
Set objArgs = WScript.Arguments
Select Case objArgs.Count
Case 1:
    strHostName = objArgs(0)
    nHostPort = smtpPortDefault
Case 2:
    strHostName = objArgs(0)
    nHostPort = objArgs(1)
Case 3:
	WScript.StdErr.WriteLine "You must specify a password with the username"
	WScript.Quit(1)
Case 4:
    strHostName = objArgs(0)
    nHostPort = objArgs(1)
	strUserName = objArgs(2)
	strPassword = objArgs(3)
Case Else
    WScript.StdErr.WriteLine "Usage: " & WScript.ScriptName & " hostname [port] [username] [password]"
    WScript.Quit(1)
End Select

'
' Read the email address of the sender from standard input
'
Do While Len(strFrom) = 0
    WScript.StdOut.Write "From: "
    strFrom = WScript.StdIn.ReadLine
Loop

'
' Read the email address of the recipientfrom standard input
'
Do While Len(strTo) = 0
    WScript.StdOut.Write "To: "
    strTo = WScript.StdIn.ReadLine
Loop

'
' Read the subject of the message from standard input
'
WScript.StdOut.Write "Subject: "
strSubject = WScript.StdIn.ReadLine

'
' Read the email address of the recipientfrom standard input;
' note that this basic implementation only supports a single
' recipient, and it must be in user@domain.tld format
'
WScript.StdOut.Write "Cc: "
strCc = WScript.StdIn.ReadLine

WScript.StdOut.WriteLine
WScript.StdOut.WriteLine "Enter your message below, press Ctrl+Z when finished"

'
' Read the body of the message from standard input, a line at a time
' and send it to the mail server; note that if you take too long to
' enter the message interactively, the server may timeout the session;
' the exact amount of time depends on the server's configuration
'
Do While Not WScript.StdIn.AtEndOfStream
    strMessage = strMessage & WScript.StdIn.ReadLine & vbCrLf
Loop

nError = objMail.ComposeMessage(strFrom, strTo, strCc, , strSubject, strMessage)
If nError <> 0 Then
    WScript.StdErr.WriteLine "Error " & objMail.LastError & ": " & objMail.LastErrorString
    WScript.Quit(1)
End If

strSender = objMail.ParseAddress(strFrom)

For nIndex = 0 To objMail.Recipients - 1
	If Len(strRecipients) > 0 Then strRecipients = strRecipients & ", "
	strRecipients = strRecipients & objMail.Recipient(nIndex)
Next

objSmtp.Extended = True

nError = objSmtp.Connect(strHostName, nHostPort)
If nError <> 0 Then
    WScript.StdErr.WriteLine "Error " & objSmtp.LastError & ": " & objSmtp.LastErrorString
    WScript.Quit(1)
End If

If Len(strUserName) > 0 Then
	nError = objSmtp.Authenticate(strUserName, strPassword)
	If nError <> 0 Then
    	WScript.StdErr.WriteLine "Error " & objSmtp.LastError & ": " & objSmtp.LastErrorString
    	WScript.Quit(1)
	End If
End If
    
nError = objSmtp.SendMessage(strSender, strRecipients, objMail.Message)
If nError <> 0 Then
    WScript.StdErr.WriteLine "Error " & objSmtp.LastError & ": " & objSmtp.LastErrorString
	If nError = 12296 Then ' No valid recipients
	    WScript.StdErr.WriteLine "This server may require authentication to relay messages."
	    WScript.StdErr.WriteLine "Try specifying a username and password and submit the message again."
	End If
    WScript.Quit(1)
End If

WScript.StdOut.WriteLine
WScript.StdOut.WriteLine "Your message has been accepted for " & strRecipients

objSmtp.Disconnect
objSmtp.Uninitialize
objMail.Uninitialize
