' SocketTools 10 ActiveX Edition
' Copyright 2023 Catalyst Development Corporation
' All rights reserved
'
' This file is licensed to you pursuant to the terms of the
' product license agreement included with the original software,
' and is protected by copyright law and international treaties.
' Unauthorized reproduction or distribution may result in severe
' criminal penalties.
'

'
' Retrieve the specified page from a web server and write the
' contents to standard output. The parameter should specify the
' URL of the page to display
'
Option Explicit

Const httpTransferDefault = 0
Const httpTransferConvert = 1

Dim objArgs
Dim objHttp
Dim strLicenseKey
Dim strRemoteURL
Dim strBuffer
Dim nLength
Dim nArg, nError

'
' Process command line arguments, making sure that a hostname
' has been specified and setting the strHostName and strFileName
' variables
'
Set objArgs = WScript.Arguments
If objArgs.Count < 1 Or objArgs.Count > 2 Then
    WScript.StdErr.WriteLine "Usage: " & WScript.ScriptName & " url"
    WScript.Quit(1)
End If

If objArgs.Count = 1 Then
    strRemoteURL = objArgs(0)
Else
    strRemoteURL = objArgs(0)
End If

'
' Create an instance of the control
'
Set objHttp = WScript.CreateObject("SocketTools.HttpClient.10")

'
' Initialize the object using the specified runtime license key;
' if the key is not specified, the development license will be used
'
strLicenseKey = "" ' Should be set to the runtime license key
nError = objHttp.Initialize(strLicenseKey) 
If nError <> 0 Then
    WScript.Echo "Unable to initialize SocketTools component"
    WScript.Quit(1)
End If
    
' Setup error handling since the component will throw an error
' if an invalid URL is specified

On Error Resume Next: Err.Clear
objHttp.URL = strRemoteURL

' Check the Err object to see if an error has occurred, and
' if so, let the user know that the URL is invalid

If Err.Number <> 0 Then
    WScript.StdErr.WriteLine "The specified URL is invalid"
    WScript.Quit(1)
End If

' Reset error handling and connect to the server using the
' default property values that were updated when the URL
' property was set (ie: HostName, RemotePort, UserName, etc.)
On Error GoTo 0
nError = objHttp.Connect()

If nError <> 0 Then
    WScript.StdErr.WriteLine "Error " & objHttp.LastError & ": " & objHttp.LastErrorString
    WScript.Quit(1)
End If

' Download the file to the local system
nError = objHttp.GetData(objHttp.Resource, strBuffer, nLength, httpTransferConvert)

If nError = 0 Then
    WScript.StdOut.WriteLine strBuffer
Else
    WScript.StdErr.WriteLine "Error " & objHttp.LastError & ": " & objHttp.LastErrorString
    WScript.Quit(1)
End If

objHttp.Disconnect
objHttp.Uninitialize
