VERSION 5.00
Object = "{5278BD09-BDDB-4941-A4E7-BC06219CC79A}#1.0#0"; "cswskx10.ocx"
Begin VB.Form formMain 
   Caption         =   "SocketWrench Echo Client"
   ClientHeight    =   4065
   ClientLeft      =   3300
   ClientTop       =   3780
   ClientWidth     =   6840
   ForeColor       =   &H80000008&
   LinkTopic       =   "formMain"
   PaletteMode     =   1  'UseZOrder
   ScaleHeight     =   4065
   ScaleWidth      =   6840
   Begin SocketWrenchCtl.SocketWrench socketClient 
      Left            =   6300
      Top             =   3540
      _cx             =   741
      _cy             =   741
   End
   Begin VB.CommandButton cmdAction 
      Caption         =   "Send"
      Default         =   -1  'True
      Height          =   360
      Left            =   5220
      TabIndex        =   2
      Top             =   3480
      Width           =   855
   End
   Begin VB.TextBox viewOutput 
      BorderStyle     =   0  'None
      BeginProperty Font 
         Name            =   "Courier New"
         Size            =   9.75
         Charset         =   0
         Weight          =   400
         Underline       =   0   'False
         Italic          =   0   'False
         Strikethrough   =   0   'False
      EndProperty
      Height          =   3255
      Left            =   60
      MousePointer    =   1  'Arrow
      MultiLine       =   -1  'True
      ScrollBars      =   3  'Both
      TabIndex        =   0
      TabStop         =   0   'False
      Top             =   120
      Width           =   6195
   End
   Begin VB.TextBox editInput 
      BeginProperty Font 
         Name            =   "Courier New"
         Size            =   9.75
         Charset         =   0
         Weight          =   400
         Underline       =   0   'False
         Italic          =   0   'False
         Strikethrough   =   0   'False
      EndProperty
      Height          =   360
      Left            =   0
      TabIndex        =   1
      Top             =   3480
      Width           =   5115
   End
   Begin VB.Menu menuConnection 
      Caption         =   "Connection"
      Begin VB.Menu menuConnect 
         Caption         =   "&Connect"
      End
      Begin VB.Menu menuDisconnect 
         Caption         =   "&Disconnect"
      End
      Begin VB.Menu menuSeparator1 
         Caption         =   "-"
      End
      Begin VB.Menu menuExit 
         Caption         =   "E&xit"
      End
   End
End
Attribute VB_Name = "formMain"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = False
Attribute VB_PredeclaredId = True
Attribute VB_Exposed = False
' SocketWrench 10.0
' Copyright 2023 Catalyst Development Corporation
' All rights reserved
'
' This file is licensed to you pursuant to the terms of the
' product license agreement included with the original software,
' and is protected by copyright law and international treaties.
' Unauthorized reproduction or distribution may result in severe
' criminal penalties.
'
Option Explicit

Dim g_bInitialized As Integer
Dim g_bCanceled As Integer

Private Sub cmdAction_Click()
    Dim strBuffer As String
    Dim cchBuffer As Integer
    Dim nBytesWritten As Integer
    Dim nBytesRead As Integer

    If cmdAction.Caption = "Cancel" Then
        '
        ' If the button caption reads 'Cancel' then this means
        ' that we are in the process of reading data from the
        ' server, and the user wishes to cancel the operation
        '
        g_bCanceled = True
        cmdAction.Enabled = False
        socketClient.Cancel
        Exit Sub
    End If

    cmdAction.Enabled = False

    nBytesWritten = 0
    nBytesRead = 0

    '
    ' Send the string entered by the user, terminated with
    ' a carriage-return/linefeed sequence; this is commonly
    ' used as an 'end of line' delimiter by the text-based
    ' Internet application protocols such as FTP and SMTP.
    '
    strBuffer = editInput.Text + Chr(13) + Chr(10)
    cchBuffer = Len(strBuffer)

    editInput.Text = ""

    '
    ' Write the data to the socket
    '
    nBytesWritten = socketClient.Write(strBuffer, cchBuffer)
    
    If nBytesWritten = -1 Then
        MsgBox "Unable to send data to the remote host (Error " & socketClient.LastError & ")", vbExclamation, App.Title
        Exit Sub
    End If

    '
    ' If this is not a blocking socket, then exit after
    ' sending the data; when the server echoes the data
    ' back to us, the control's Read event will fire
    '
    If socketClient.Blocking = False Then
        Exit Sub
    End If
    
    '
    ' Because this is a blocking connection, give the user
    ' the opportunity to cancel the blocking read and
    ' return control back to the application; this will be
    ' implemented using the global flag g_bCanceled, along
    ' with the SOCKET_CANCEL action
    '
    g_bCanceled = False
    cmdAction.Caption = "Cancel"
    cmdAction.Enabled = True

    '
    ' Read the data echoed back from the server. The most
    ' important aspect of this code is that we do not make
    ' the assumption that we will be able to read all of
    ' the data in a single operation. Instead, we use a loop
    ' to read until the number of bytes read matches the
    ' number of bytes written.
    '
    Do While nBytesRead < nBytesWritten And g_bCanceled = False
        
        cchBuffer = socketClient.Read(strBuffer, nBytesWritten)
        
        If cchBuffer > 0 Then
            '
            ' The read on the socket has returned at least one
            ' byte of data; update the total number of bytes read
            ' and the viewOutput edit control
            '
            nBytesRead = nBytesRead + cchBuffer
            '
            ' Make sure that we don't have more data than can be stored
            ' in the edit control
            '
            If CLng(Len(viewOutput.Text)) + CLng(cchBuffer) > 30000& Then
                viewOutput.Text = Right(viewOutput.Text, 5000)
            End If
            
            viewOutput.SelStart = 65535
            viewOutput.SelLength = 0
            viewOutput.SelText = strBuffer
            viewOutput.Refresh
        
        ElseIf cchBuffer = 0 Then
            '
            ' The server has closed the connection; we must close
            ' our side of the connection and let the user know
            ' that the client session is terminated
            '
            Call menuDisconnect_Click
            MsgBox "The remote server has closed the connection", vbInformation, App.Title
            Exit Do
        
        Else
            '
            ' The read on the socket has failed with an error
            '
            Select Case socketClient.LastError
            Case swErrorOperationCanceled:
            Case swErrorInvalidHandle:
                '
                ' The read was canceled by the user (swErrorOperationCanceled) or the user
                ' has closed the connection to the server (swErrorInvalidHandle)
                '
                Exit Do

            Case swErrorOperationTimeout:
                '
                ' The read has timed out; stop reading and presume that
                ' the server has no more data for us
                '
                Exit Do

            Case Else
                '
                ' An unexpected error occurred during the read
                '
                MsgBox "An unexpected error occurred (Error " & socketClient.LastError & ")"
                Exit Do
            End Select
        End If
        DoEvents
    Loop

    cmdAction.Caption = "Send"
    UpdateForm
End Sub

Private Sub editInput_Change()
    UpdateForm
End Sub

Private Sub Form_Activate()
    If g_bInitialized = False Then
        g_bInitialized = True
        Call menuConnect_Click
    End If
End Sub

Private Sub Form_Load()
    g_bInitialized = False
    g_bCanceled = False
    UpdateForm
End Sub

Private Sub Form_Resize()
    If WindowState <> vbMinimized Then
        viewOutput.Top = 0
        viewOutput.Left = 0
        viewOutput.Height = ScaleHeight - editInput.Height
        viewOutput.Width = ScaleWidth
        editInput.Top = ScaleHeight - editInput.Height
        editInput.Left = 0
        editInput.Width = ScaleWidth - cmdAction.Width
        cmdAction.Height = editInput.Height
        cmdAction.Top = ScaleHeight - cmdAction.Height
        cmdAction.Left = ScaleWidth - cmdAction.Width
    End If
End Sub

Private Sub Form_Unload(Cancel As Integer)
    Dim nError As Integer
    If socketClient.IsConnected Then
        nError = socketClient.Disconnect
        If (nError <> 0) Then
            MsgBox "Unable to disconnect.  Error " & nError
        End If
    End If
End Sub

Private Sub menuConnect_Click()
    formConnect.Show vbModal
    UpdateForm
    
    If socketClient.IsConnected Then
        editInput.Text = "": viewOutput.Text = ""
        editInput.SetFocus
    End If

End Sub

Private Sub menuDisconnect_Click()
    Dim nError As Integer
    nError = socketClient.Disconnect
    If (nError <> 0) Then
        MsgBox "Unable to disconnect.  Error " & nError
    End If
    UpdateForm
End Sub

Private Sub menuExit_Click()
    Dim nError As Integer

    If socketClient.IsConnected Then
        nError = socketClient.Disconnect
        If (nError <> 0) Then
            MsgBox "Unable to disconnect.  Error " & nError
        End If
    End If
    End
End Sub


Private Sub socketClient_OnConnect()
    '
    ' This event is called when a non-blocking (asynchronous)
    ' connection attempt has completed
    '
    UpdateForm
    
    viewOutput.Text = ""
    editInput.Text = ""
    editInput.SetFocus
End Sub

Private Sub socketClient_OnDisconnect()
    '
    ' This event is called when the remote host closes
    ' the connection. Note that we must still explicitly
    ' close our socket.
    '
    Call menuDisconnect_Click
    MsgBox "The remote server has closed the connection", vbInformation, App.Title
    
End Sub

Private Sub socketClient_OnRead()
    '
    ' This event is fired when data is written by the server to
    ' the client. This event is only fired when the control is
    ' in non-blocking mode (when the Blocking property is set
    ' to False); the code for the blocking read is in the Click
    ' event for the cmdAction control
    '
    Dim strBuffer As String
    Dim cchBuffer As Integer

    '
    ' Read the data echoed back from the server. The most
    ' important aspect of this code is that we do not make
    ' the assumption that we will be able to read all of
    ' the data in a single operation.
    '
    On Error Resume Next: Err.Clear
    Do
        cchBuffer = socketClient.Read(strBuffer, 4096)

        If cchBuffer > 0 Then
            '
            ' Make sure that we don't have more data than can be stored
            ' in the edit control
            '
            If CLng(Len(viewOutput.Text)) + CLng(cchBuffer) > 30000& Then
                viewOutput.Text = Right(viewOutput.Text, 5000)
            End If
            
            viewOutput.SelStart = 65535
            viewOutput.SelLength = 0
            viewOutput.SelText = strBuffer
            viewOutput.Refresh
        
        ElseIf cchBuffer = 0 Then
            '
            ' If the number of bytes read is 0, then this means
            ' that the server has closed the connection; the
            ' control's Disconnect event will fire
            '
            If cchBuffer = 0 Then Exit Do
        Else
            '
            ' The read on the socket has failed with an error
            '
            Select Case socketClient.LastError
            Case swErrorOperationCanceled:
            Case swErrorInvalidHandle:
                '
                ' The read was canceled by the user (swErrorOperationCanceled) or the user
                ' has closed the connection to the server (swErrorInvalidHandle)
                '
                Exit Do

            Case swErrorOperationWouldBlock:
                '
                ' There is no more data to read at this time; if the server
                ' sends more data, another Read event will fire
                '
                Exit Do

            Case Else
                '
                ' An unexpected error occurred during the read
                '
                MsgBox "An unexpected error occurred (Error " & socketClient.LastError & ")"
                Exit Do
            End Select
        End If
        DoEvents
    Loop
    On Error GoTo 0

End Sub

Private Sub UpdateForm()
    If socketClient.IsConnected Then
        If Len(socketClient.HostName) > 0 Then
            formMain.Caption = socketClient.HostName & " - " & App.Title
        Else
            formMain.Caption = socketClient.HostAddress & " - " & App.Title
        End If
        menuConnect.Enabled = False
        menuDisconnect.Enabled = True
        editInput.Enabled = True
        If Len(editInput.Text) > 0 Then cmdAction.Enabled = True Else cmdAction.Enabled = False
    Else
        formMain.Caption = App.Title
        menuConnect.Enabled = True
        menuDisconnect.Enabled = False
        editInput.Enabled = False
        cmdAction.Enabled = False
    End If
End Sub

Private Sub viewOutput_KeyPress(KeyAscii As Integer)
    If KeyAscii > 31 Then KeyAscii = 0
End Sub

